//+------------------------------------------------------------------+
//|                                                   Indicators.mqh |
//|          Copyright 2015, Vasiliy Sokolov, St.Petersburg, Russia. |
//|                              https://login.mql5.com/ru/users/c-4 |
//+------------------------------------------------------------------+
#property copyright "Copyright 2014, Vasiliy Sokolov."
#property link      "http://www.mql5.com"

//+------------------------------------------------------------------+
//|       .  |
//+------------------------------------------------------------------+
class CIndicators
{
public:
   double iHighest(string symbol, ENUM_TIMEFRAMES tf, int count, int start_pos=1);
   double iLowest(string symbol, ENUM_TIMEFRAMES tf, int count, int start_pos=1);
   double iClose(string symbol, ENUM_TIMEFRAMES tf, int shift);
   double iRSI(string symbol, ENUM_TIMEFRAMES tf, int period, ENUM_APPLIED_PRICE applied, int shift);
   double iCCI(string symbol, ENUM_TIMEFRAMES tf, int period, ENUM_APPLIED_PRICE applied, int shift);
};

//+------------------------------------------------------------------+
//|             |
//| count ,   start_pos .                          |
//|  start_pos .                                               |
//| INPUT PARAMETERS                                                 |
//|   symbol -  .                                   |
//|   tf -  ,  NULL,        |
//|          (.  ENUM_TIMEFRAMES).     |
//|   count -                       |
//|   start_pos=1 -  ,             |
//|                 .                                       |
//| RESULT                                                           |
//|      count .  -       |
//|    .                                                    | 
//+------------------------------------------------------------------+
double CIndicators::iHighest(string symbol, ENUM_TIMEFRAMES tf, int count, int start_pos=1)
{
//---
   double high[];
   CopyHigh(symbol, tf, start_pos, count, high);
   if(ArraySize(high) == 0)return 0.0;
   double max = high[ArrayMaximum(high)];
   return max;
//---
}
//+------------------------------------------------------------------+
//|       count ,      |
//|   start_pos .                                       |
//| INPUT PARAMETERS                                                 |
//|   symbol -  .                                   |
//|   tf -  ,  NULL,        |
//|          (.  ENUM_TIMEFRAMES).     |
//|   count -                       |
//|   start_pos=1 -  ,             |
//|                 .                                       |
//| RESULT                                                           |
//|      count .  -       |
//|    .                                                    | 
//+------------------------------------------------------------------+
double CIndicators::iLowest(string symbol, ENUM_TIMEFRAMES tf, int count, int start_pos=1)
{
//---
   double low[];
   CopyLow(symbol, tf, start_pos, count, low);
   if(ArraySize(low) == 0)return 0.0;
   double min = low[ArrayMinimum(low)];
   return min;
//---
}
//+------------------------------------------------------------------+
//|      (     |
//| shift)  .                                 |
//| INPUT PARAMETERS                                                 |
//|   symbol -  .                                   |
//|   tf -  ,  NULL,        |
//|          (.  ENUM_TIMEFRAMES).     |
//|   shift -     .                 |
//| RESULT                                                           |
//|     .  -                     |
//|    .                                                    | 
//+------------------------------------------------------------------+
double CIndicators::iClose(string symbol, ENUM_TIMEFRAMES tf, int shift)
{
   double close[];
   CopyClose(symbol, tf, shift, 1, close);
   if(ArraySize(close))
      return close[0];
   return 0.0;
}
//+------------------------------------------------------------------+
//|    RSI     shift.   |
//| INPUT PARAMETERS                                                 |
//|   symbol -  .                                   |
//|   tf -  ,  NULL,        |
//|          (.  ENUM_TIMEFRAMES).     |
//|   shift -     .                 |
//| RESULT                                                           |
//|     RSI.  -                |
//|    .                                                    | 
//+------------------------------------------------------------------+
double CIndicators::iRSI(string symbol, ENUM_TIMEFRAMES tf, int period, ENUM_APPLIED_PRICE applied, int shift)
{
//---   
   int hRSI = iRSI(symbol, tf, period, applied);
   if(hRSI == INVALID_HANDLE)
      return 0.0;
   double rsi[];
   CopyBuffer(hRSI, 0, shift, 1, rsi);
   if(ArraySize(rsi))
      return rsi[0];
   return 0.0;
//---
}
//+------------------------------------------------------------------+
//|    CCI     shift.   |
//| INPUT PARAMETERS                                                 |
//|   symbol -  .                                   |
//|   tf -  ,  NULL,        |
//|          (.  ENUM_TIMEFRAMES).     |
//|   shift -     .                 |
//| RESULT                                                           |
//|     CCI.  -                |
//|    .                                                    | 
//+------------------------------------------------------------------+
double CIndicators::iCCI(string symbol, ENUM_TIMEFRAMES tf, int period, ENUM_APPLIED_PRICE applied, int shift)
{
   int hCCI = iCCI(Symbol(), PERIOD_CURRENT, 55, PRICE_CLOSE);
   if(hCCI == INVALID_HANDLE)return 0.0;
   double cci[];
   ArrayResize(cci, 1);
   CopyBuffer(hCCI, 0, 0, 1, cci);
   return cci[0];
}